@@ -685,7 +685,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "permission": role
         }
 
-        url = self._base_url+"/smartbot/agents/{}/share/entries".format(self._agentId)
+        url = self._base_url_askdata+"/smartbot/agents/{}/share/entries".format(self._agentId)
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -702,7 +702,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         user_id = self.__get_user_by_email(user_email)
 
-        channel_id = self.get_channel(channel_slug)
+        channel_id = self.get_channel(channel_slug)["id"]
         self.__add_user_to_ch(channel_id, user_id, role)
 
     def __add_user_to_ch(self, channel_id, user_id, role="FOLLOWER"):
@@ -718,7 +718,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url + "/smartfeed/channels/{}/users".format(channel_id)
+        authentication_url = self._base_url_askdata + "/smartfeed/channels/{}/users".format(channel_id)
         r = s.post(url=authentication_url, headers=self._headers, json=data)
         r.raise_for_status()
         #return r
