@@ -254,8 +254,6 @@ class Insight_Definition:
 
         position = (len(self.components))
         body = {"type": "table", "position": position}
-        print("BODY")
-        print(body)
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -413,8 +411,6 @@ class Insight_Definition:
         r = response.json()
         columns = r["schema"]
 
-        print(columns)
-
         upper_params = []
         for param in params:
             for column in columns:
@@ -675,7 +671,6 @@ class Insight_Definition:
             "variableName": variable_name,
             "qcId": qc_id
         }
-        print(body)
         url = self._base_url_askdata+"/smartinsight/definitions/"+self.definition_id+"/data_queries/"+data_id
         s = requests.Session()
         s.keep_alive = False
