@@ -84,6 +84,8 @@ def read(type, settings):
         return __read_csv(settings)
     if type == "EXCEL":
         return __read_excel(settings)
+    if type == "PARQUET":
+        return __read_parquet(settings)
     if type == "GSHEET":
         return __read_gsheet(settings)
     if type == "Hubspot":
@@ -93,7 +95,6 @@ def read(type, settings):
 
 
 def __read_csv(settings: dict):
-    #df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], parse_dates=[i for i in range(len(pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"]).columns))])
     
     # Handle thousands
     if settings["thousands"] == "None":
@@ -116,8 +117,22 @@ def __read_csv(settings: dict):
 
     return df
 
+def __read_parquet(settings: dict):
+    
+    df = pd.read_parquet(path=settings["path"])
+
+    return df
+
 def __read_excel(settings: dict):
-    df = pd.read_excel(settings["path"], parse_dates=[i for i in range(len(pd.read_excel(settings["path"]).columns))])
+    df = pd.read_excel(settings["path"])
+
+    # Detect if any column is a date-time
+    for col in df.columns:
+        if df[col].dtype == 'object':
+            try:
+                df[col] = pd.to_datetime(df[col])
+            except ValueError:
+                pass
 
     return df
 
